DefinitionBlock ("SSDT-USB.aml", "SSDT", 1, "sample", "USBFix", 0x00003000)
{
    // "USBInjectAllConfiguration" : override settings for USBInjectAll.kext
    Device(UIAC)
    {
        Name(_HID, "UIA00000")
        // "RehabManConFiguration"
        Name(RMCF, Package()
        {
            // XHC overrides for Gigabyte GA-Z270XP-SLI (rev 1.0) board
            "8086_a2af", Package()   // 02af is the USB Device ID for 200-series board
            {
                "port-count", Buffer() { 0x1a, 0, 0, 0}, // Highest port number is SS10 at port 0x1a, we have 19 ports and must exclude 4  H     uia_exclude=HS09;SS09;HS10;SS10 both USB under NIC
                "ports", Package()
                {
                    "HS01", Package() // USB2 #1 on USB3 header #1 on motherboard, port <01 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x01, 0, 0, 0 },
                    },
                    "HS02", Package() // USB2 #2 on USB3 header #1 on motherboard, port <02 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x02, 0, 0, 0 },
                    },
                    "HS03", Package() // USB2 on bottom USB3 port, right of PS/2 port, port <03 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x03, 0, 0, 0 },
                    },
                    "HS04", Package() // USB2 on top USB3 port, right of PS/2 port, port <04 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x04, 0, 0, 0 },
                    },
                    "HS07", Package() // USB2 on bottom USB3 port, right of HDMI port, port <07 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x07, 0, 0, 0 },
                    },
                    "HS08", Package() // USB2 on top USB3 port, right of HDMI port, port <08 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x08, 0, 0, 0 },
                    },
                    "HS09", Package() // USB2 on bottom USB3 port, below Intel Ethernet port, port <09 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x09, 0, 0, 0 },
                    },
                    "HS10", Package() // USB2 on top USB3 port, below Intel Ethernet port, port <0a 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x0a, 0, 0, 0 },
                    },
                    "HS11", Package() // USB2 on USB2 header #1 on motherboard - goes to front panel, port <0b 00 00 00>
                    {
                        "UsbConnector", 0,  // 0 because it is a USB2 header
                        "port", Buffer() { 0x0b, 0, 0, 0 },
                    },
                    "HS12", Package() // USB2 on USB2 header #1 on motherboard - goes to front panel, port <0c 00 00 00>
                    {
                        "UsbConnector", 0,  // 0 because it is a USB2 header
                        "port", Buffer() { 0x0c, 0, 0, 0 },
                    },
                    "HS14", Package() // USB2 on USB2 header #2, port #2 on motherboard , port <0e 00 00 00>
                    {
                        "UsbConnector", 255,  // 255 because this is used for PCI-e Broadcom/Bluetooth adapter
                        "port", Buffer() { 0x0e, 0, 0, 0 },
                    },
                    "SS01", Package() // USB3 #1 on USB3 header #1 on motherboard, port <11 00 00 00>,
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x11, 0, 0, 0 },
                    },
                    "SS02", Package() // USB3 #1 on USB3 header #1 on motherboard, port <12 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x12, 0, 0, 0 },
                    },
                    "SS03", Package() // USB3 on bottom USB3 port, right of PS/2 port, port <13 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x13, 0, 0, 0 },
                    },
                    "SS04", Package() // USB2 on top USB3 port, right of PS/2 port, port <14 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x14, 0, 0, 0 },
                    },
                    "SS07", Package() // USB3 on bottom USB3 port, right of HDMI port, port <17 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x17, 0, 0, 0 },
                    },
                    "SS08", Package() // USB3 on top USB3 port, right of HDMI port, port <18 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x18, 0, 0, 0 },
                    },                    
                    "SS09", Package() // USB3 on top USB3 port, below Intel Ethernet port, port <19 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x19, 0, 0, 0 },
                    },
                    "SS10", Package() // USB3 on bottom USB3 port, below Intel Ethernet port, port <1a 00 00 00>
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 0x1a, 0, 0, 0 },
                    },
                },
            },
        })
    }
    // Inject Fake EC device
    Device(_SB.EC)
    {
        Name(_HID, "EC000000")
    }
    // USB power properties via USBX device
    Device(_SB.USBX)
    {
        Name(_ADR, 0)
        Method (_DSM, 4)
        {
            If (!Arg2) { Return (Buffer() { 0x03 } ) }
            Return (Package()
            {
                // these values from iMac17,1
                "kUSBSleepPortCurrentLimit", 2100,
                "kUSBSleepPowerSupply", 5100,
                "kUSBWakePortCurrentLimit", 2100,
                "kUSBWakePowerSupply", 5100,
            })
        }
    }
}